.. module:: wwdtm.pronoun

***************
Module: pronoun
***************

This module provides objects used to retrieve pronouns information from
a copy of the Wait Wait Don't Tell Me! Stats database.

Pronouns
========

.. autoclass:: wwdtm.pronoun.Pronouns
    :members:
    :inherited-members:
